==> qtjambi-opengl-debuginfo-linux-x64-6.5.8.jar: sources/QtJambiOpenGL/QOpenGLVersionFunctionsFactory_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtOpenGL/qopenglversionfunctionsfactory.h>
#include <QtCore/QVariant>
#include <QtGui/qopenglcontext.h>
#include <QtOpenGL/qopenglversionfunctions.h>
#include <QtOpenGL/qopenglversionprofile.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

// emitting (writeClassCodeInjections)
QAbstractOpenGLFunctions* qtjambi_QOpenGLVersionFunctionsFactory_get(JNIEnv *__jni_env, jclass type, QOpenGLContext* context);

void deleter_QOpenGLVersionFunctionsFactory(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QOpenGLVersionFunctionsFactory")
    QOpenGLVersionFunctionsFactory *_ptr = reinterpret_cast<QOpenGLVersionFunctionsFactory *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QOpenGLVersionFunctionsFactory()
void __qt_construct_QOpenGLVersionFunctionsFactory(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QOpenGLVersionFunctionsFactory()")
    Q_UNUSED(__java_arguments)
    QOpenGLVersionFunctionsFactory *__qt_this = new(__qtjambi_ptr) QOpenGLVersionFunctionsFactory();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QOpenGLVersionFunctionsFactory::QOpenGLVersionFunctionsFactory()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_opengl_QOpenGLVersionFunctionsFactory_initialize_1native__Lio_qt_opengl_QOpenGLVersionFunctionsFactory_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QOpenGLVersionFunctionsFactory::QOpenGLVersionFunctionsFactory()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QOpenGLVersionFunctionsFactory, sizeof(QOpenGLVersionFunctionsFactory), typeid(QOpenGLVersionFunctionsFactory), 0, false, &deleter_QOpenGLVersionFunctionsFactory, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QOpenGLVersionFunctionsFactory
void __qt_destruct_QOpenGLVersionFunctionsFactory(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QOpenGLVersionFunctionsFactory")
    reinterpret_cast<QOpenGLVersionFunctionsFactory*>(ptr)->~QOpenGLVersionFunctionsFactory();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QOpenGLVersionFunctionsFactory::get(QOpenGLVersionProfile,QOpenGLContext*)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_opengl_QOpenGLVersionFunctionsFactory_get_1native_1cref_1QOpenGLVersionProfile_1QOpenGLContext_1ptr__JJ)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID versionProfile0,
 QtJambiNativeID context1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QOpenGLVersionFunctionsFactory::get(QOpenGLVersionProfile,QOpenGLContext*)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QOpenGLVersionProfile& __qt_versionProfile0 = QtJambiAPI::valueReferenceFromNativeId<QOpenGLVersionProfile>(versionProfile0);
        QOpenGLContext* __qt_context1 = QtJambiAPI::objectFromNativeId<QOpenGLContext>(context1);
        QAbstractOpenGLFunctions* __qt_return_value = QOpenGLVersionFunctionsFactory::get(__qt_versionProfile0, __qt_context1);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QOpenGLVersionFunctionsFactory::get<QAbstractOpenGLFunctions>(QOpenGLContext*)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_opengl_QOpenGLVersionFunctionsFactory_get_1native_1QOpenGLContext_1ptr__Ljava_lang_Class_2J)
(JNIEnv *__jni_env,
 jclass,
 jclass type,
 QtJambiNativeID context0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QOpenGLVersionFunctionsFactory::get<QAbstractOpenGLFunctions>(QOpenGLContext*)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QOpenGLContext* __qt_context0 = QtJambiAPI::objectFromNativeId<QOpenGLContext>(context0);
        auto __qt_return_value = qtjambi_QOpenGLVersionFunctionsFactory_get(__jni_env, type, __qt_context0);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QOpenGLVersionFunctionsFactory(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QOpenGLVersionFunctionsFactory>("QOpenGLVersionFunctionsFactory", "io/qt/opengl/QOpenGLVersionFunctionsFactory");
// BEGIN: function table
    registerConstructorInfos(typeId, 0, &__qt_destruct_QOpenGLVersionFunctionsFactory, {
        ConstructorInfo(&__qt_construct_QOpenGLVersionFunctionsFactory, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QOpenGLVersionFunctionsFactory);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-opengl-debuginfo-linux-x64-6.6.3.jar: sources/QtJambiOpenGL/QOpenGLVersionFunctionsFactory_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtOpenGL/qopenglversionfunctionsfactory.h>
#include <QtCore/QVariant>
#include <QtGui/qopenglcontext.h>
#include <QtOpenGL/qopenglversionfunctions.h>
#include <QtOpenGL/qopenglversionprofile.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

// emitting (writeClassCodeInjections)
QAbstractOpenGLFunctions* qtjambi_QOpenGLVersionFunctionsFactory_get(JNIEnv *__jni_env, jclass type, QOpenGLContext* context);

void deleter_QOpenGLVersionFunctionsFactory(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QOpenGLVersionFunctionsFactory")
    QOpenGLVersionFunctionsFactory *_ptr = reinterpret_cast<QOpenGLVersionFunctionsFactory *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QOpenGLVersionFunctionsFactory()
void __qt_construct_QOpenGLVersionFunctionsFactory(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QOpenGLVersionFunctionsFactory()")
    Q_UNUSED(__java_arguments)
    QOpenGLVersionFunctionsFactory *__qt_this = new(__qtjambi_ptr) QOpenGLVersionFunctionsFactory();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QOpenGLVersionFunctionsFactory::QOpenGLVersionFunctionsFactory()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_opengl_QOpenGLVersionFunctionsFactory_initialize_1native__Lio_qt_opengl_QOpenGLVersionFunctionsFactory_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QOpenGLVersionFunctionsFactory::QOpenGLVersionFunctionsFactory()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QOpenGLVersionFunctionsFactory, sizeof(QOpenGLVersionFunctionsFactory), typeid(QOpenGLVersionFunctionsFactory), false, &deleter_QOpenGLVersionFunctionsFactory, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QOpenGLVersionFunctionsFactory
void __qt_destruct_QOpenGLVersionFunctionsFactory(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QOpenGLVersionFunctionsFactory")
    reinterpret_cast<QOpenGLVersionFunctionsFactory*>(ptr)->~QOpenGLVersionFunctionsFactory();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QOpenGLVersionFunctionsFactory::get(QOpenGLVersionProfile,QOpenGLContext*)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_opengl_QOpenGLVersionFunctionsFactory_get_1native_1cref_1QOpenGLVersionProfile_1QOpenGLContext_1ptr__JJ)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID versionProfile0,
 QtJambiNativeID context1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QOpenGLVersionFunctionsFactory::get(QOpenGLVersionProfile,QOpenGLContext*)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QOpenGLVersionProfile& __qt_versionProfile0 = QtJambiAPI::valueReferenceFromNativeId<QOpenGLVersionProfile>(versionProfile0);
        QOpenGLContext* __qt_context1 = QtJambiAPI::objectFromNativeId<QOpenGLContext>(context1);
        QAbstractOpenGLFunctions* __qt_return_value = QOpenGLVersionFunctionsFactory::get(__qt_versionProfile0, __qt_context1);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QOpenGLVersionFunctionsFactory::get<QAbstractOpenGLFunctions>(QOpenGLContext*)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_opengl_QOpenGLVersionFunctionsFactory_get_1native_1QOpenGLContext_1ptr__Ljava_lang_Class_2J)
(JNIEnv *__jni_env,
 jclass,
 jclass type,
 QtJambiNativeID context0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QOpenGLVersionFunctionsFactory::get<QAbstractOpenGLFunctions>(QOpenGLContext*)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QOpenGLContext* __qt_context0 = QtJambiAPI::objectFromNativeId<QOpenGLContext>(context0);
        auto __qt_return_value = qtjambi_QOpenGLVersionFunctionsFactory_get(__jni_env, type, __qt_context0);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QOpenGLVersionFunctionsFactory(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QOpenGLVersionFunctionsFactory>("QOpenGLVersionFunctionsFactory", "io/qt/opengl/QOpenGLVersionFunctionsFactory");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QOpenGLVersionFunctionsFactory, {
        ConstructorInfo(&__qt_construct_QOpenGLVersionFunctionsFactory, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QOpenGLVersionFunctionsFactory);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
